@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -57,5 +57,5 @@ void ExternalComposerConfigureDialog::reset()
 
 void ExternalComposerConfigureDialog::help()
 {
-    showHelp(QStringLiteral("kmail2"), QString());
+    showHelp(QStringLiteral("kmail2"), mConfigureWidget->helpAnchor());
 }
