@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,7 +20,7 @@
 
 #include <QWidget>
 
-class KComboBox;
+class QComboBox;
 class QStackedWidget;
 
 namespace MailMerge {
@@ -46,7 +46,7 @@ private Q_SLOTS:
     void slotSourceChanged(int index);
 
 private:
-    KComboBox *mSource = nullptr;
+    QComboBox *mSource = nullptr;
     QStackedWidget *mStackedWidget = nullptr;
     AttachmentListWidget *mAttachment = nullptr;
     MailMerge::CsvWidget *mCsvWidget = nullptr;
