@@ -292,24 +292,35 @@ public:
         //qCDebug(TEXT_CALENDAR_LOG) << "UrlHandler() (iCalendar)";
     }
 
-    Attendee::Ptr findMyself(const Incidence::Ptr &incidence, const QString &receiver) const
+    QString name() const override
+    {
+        return QStringLiteral("calendar handler");
+    }
+
+    Attendee findMyself(const Incidence::Ptr &incidence, const QString &receiver) const
     {
         const Attendee::List attendees = incidence->attendees();
-        Attendee::List::ConstIterator it;
-        Attendee::Ptr myself;
+        const auto idx = findMyself(attendees, receiver);
+        if (idx >= 0) {
+            return attendees.at(idx);
+        }
+        return {};
+    }
+
+    int findMyself(const Attendee::List &attendees, const QString &receiver) const
+    {
         // Find myself. There will always be all attendees listed, even if
         // only I need to answer it.
-        Attendee::List::ConstIterator end = attendees.constEnd();
-        for (it = attendees.constBegin(); it != end; ++it) {
+        for (int i = 0; i < attendees.size(); ++i) {
             // match only the email part, not the name
-            if (KEmailAddress::compareEmail((*it)->email(), receiver, false)) {
+            if (KEmailAddress::compareEmail(attendees.at(i).email(), receiver, false)) {
                 // We are the current one, and even the receiver, note
                 // this and quit searching.
-                myself = (*it);
+                return i;
                 break;
             }
         }
-        return myself;
+        return -1;
     }
 
     static bool heuristicalRSVP(const Incidence::Ptr &incidence)
@@ -320,9 +331,9 @@ public:
         Attendee::List::ConstIterator end(attendees.constEnd());
         for (it = attendees.constBegin(); it != end; ++it) {
             if (it == attendees.constBegin()) {
-                rsvp = (*it)->RSVP(); // use what the first one has
+                rsvp = (*it).RSVP(); // use what the first one has
             } else {
-                if ((*it)->RSVP() != rsvp) {
+                if ((*it).RSVP() != rsvp) {
                     rsvp = true; // they differ, default
                     break;
                 }
@@ -340,9 +351,9 @@ public:
 
         for (it = attendees.constBegin(); it != end; ++it) {
             if (it == attendees.constBegin()) {
-                role = (*it)->role(); // use what the first one has
+                role = (*it).role(); // use what the first one has
             } else {
-                if ((*it)->role() != role) {
+                if ((*it).role() != role) {
                     role = Attendee::OptParticipant; // they differ, default
                     break;
                 }
@@ -351,33 +362,31 @@ public:
         return role;
     }
 
-    static Attachment::Ptr findAttachment(const QString &name, const QString &iCal)
+    static Attachment findAttachment(const QString &name, const QString &iCal)
     {
         Incidence::Ptr incidence = stringToIncidence(iCal);
 
         // get the attachment by name from the incidence
         Attachment::List attachments = incidence->attachments();
-        Attachment::Ptr attachment;
-        if (!attachments.isEmpty()) {
-            const Attachment::List::ConstIterator end = attachments.constEnd();
-            for (Attachment::List::ConstIterator it = attachments.constBegin(); it != end; ++it) {
-                if ((*it)->label() == name) {
-                    attachment = *it;
-                    break;
-                }
+        Attachment attachment;
+        const Attachment::List::ConstIterator end = attachments.constEnd();
+        for (Attachment::List::ConstIterator it = attachments.constBegin(); it != end; ++it) {
+            if ((*it).label() == name) {
+                attachment = *it;
+                break;
             }
         }
 
-        if (!attachment) {
+        if (attachment.isEmpty()) {
             KMessageBox::error(
                 nullptr,
                 i18n("No attachment named \"%1\" found in the invitation.", name));
-            return Attachment::Ptr();
+            return Attachment();
         }
 
-        if (attachment->isUri()) {
+        if (attachment.isUri()) {
             bool fileExists = false;
-            QUrl attachmentUrl(attachment->uri());
+            QUrl attachmentUrl(attachment.uri());
             if (attachmentUrl.isLocalFile()) {
                 fileExists = QFile::exists(attachmentUrl.toLocalFile());
             } else {
@@ -392,7 +401,7 @@ public:
                          "organizer to resend the invitation with this attachment "
                          "stored inline instead of a link.",
                          attachmentUrl.toDisplayString()));
-                return Attachment::Ptr();
+                return Attachment();
             }
         }
         return attachment;
@@ -471,32 +480,31 @@ public:
         return receiver;
     }
 
-    Attendee::Ptr setStatusOnMyself(const Incidence::Ptr &incidence, const Attendee::Ptr &myself, Attendee::PartStat status, const QString &receiver) const
+    Attendee setStatusOnMyself(const Incidence::Ptr &incidence, const Attendee &myself, Attendee::PartStat status, const QString &receiver) const
     {
         QString name;
         QString email;
         KEmailAddress::extractEmailAddressAndName(receiver, email, name);
-        if (name.isEmpty() && myself) {
-            name = myself->name();
+        if (name.isEmpty() && !myself.isNull()) {
+            name = myself.name();
         }
-        if (email.isEmpty() && myself) {
-            email = myself->email();
+        if (email.isEmpty() && !myself.isNull()) {
+            email = myself.email();
         }
         Q_ASSERT(!email.isEmpty());   // delivery must be possible
 
-        Attendee::Ptr newMyself(
-            new Attendee(name, email, true,  // RSVP, otherwise we would not be here
+        Attendee newMyself(name, email, true,  // RSVP, otherwise we would not be here
                          status,
-                         myself ? myself->role() : heuristicalRole(incidence),
-                         myself ? myself->uid() : QString()));
-        if (myself) {
-            newMyself->setDelegate(myself->delegate());
-            newMyself->setDelegator(myself->delegator());
+                         !myself.isNull() ? myself.role() : heuristicalRole(incidence),
+                         myself.uid());
+        if (!myself.isNull()) {
+            newMyself.setDelegate(myself.delegate());
+            newMyself.setDelegator(myself.delegator());
         }
 
         // Make sure only ourselves is in the event
         incidence->clearAttendees();
-        if (newMyself) {
+        if (!newMyself.isNull()) {
             incidence->addAttendee(newMyself);
         }
         return newMyself;
@@ -662,8 +670,7 @@ public:
         return true;
     }
 
-    bool mail(Viewer *viewerInstance, const Incidence::Ptr &incidence, const QString &status, iTIPMethod method = iTIPReply, const QString &receiver = QString(),
-              const QString &to = QString(), MailType type = Answer) const
+    bool mail(Viewer *viewerInstance, const Incidence::Ptr &incidence, const QString &status, iTIPMethod method = iTIPReply, const QString &receiver = QString(), const QString &to = QString(), MailType type = Answer) const
     {
         //status is accepted/tentative/declined
         ICalFormat format;
@@ -690,17 +697,17 @@ public:
         }
 
         // Set the organizer to the sender, if the ORGANIZER hasn't been set.
-        if (incidence->organizer()->isEmpty()) {
+        if (incidence->organizer().isEmpty()) {
             QString tname, temail;
             KMime::Message::Ptr message = viewerInstance->message();
             KEmailAddress::extractEmailAddressAndName(message->sender()->asUnicodeString(),
                                                       temail, tname);
-            incidence->setOrganizer(Person::Ptr(new Person(tname, temail)));
+            incidence->setOrganizer(Person(tname, temail));
         }
 
         QString recv = to;
         if (recv.isEmpty()) {
-            recv = incidence->organizer()->fullName();
+            recv = incidence->organizer().fullName();
         }
         return mailICal(receiver, recv, msg, subject, status, type != Forward, viewerInstance);
     }
@@ -920,7 +927,7 @@ public:
             if (delegateString.isEmpty()) {
                 return true;
             }
-            if (KEmailAddress::compareEmail(delegateString, incidence->organizer()->email(), false)) {
+            if (KEmailAddress::compareEmail(delegateString, incidence->organizer().email(), false)) {
                 KMessageBox::sorry(nullptr, i18n("Delegation to organizer is not possible."));
                 return true;
             }
@@ -930,51 +937,50 @@ public:
             return false;
         }
 
-        Attendee::Ptr myself = findMyself(incidence, receiver);
+        const Attendee myself = findMyself(incidence, receiver);
 
         // find our delegator, we need to inform him as well
         QString delegator;
-        if (status != Attendee::NeedsAction && myself && !myself->delegator().isEmpty()) {
+        if (status != Attendee::NeedsAction && !myself.isNull() && !myself.delegator().isEmpty()) {
             const Attendee::List attendees = incidence->attendees();
             Attendee::List::ConstIterator end = attendees.constEnd();
             for (Attendee::List::ConstIterator it = attendees.constBegin();
                  it != end; ++it) {
-                if (KEmailAddress::compareEmail((*it)->fullName(), myself->delegator(), false)
-                    && (*it)->status() == Attendee::Delegated) {
-                    delegator = (*it)->fullName();
-                    delegatorRSVP = (*it)->RSVP();
+                if (KEmailAddress::compareEmail((*it).fullName(), myself.delegator(), false)
+                    && (*it).status() == Attendee::Delegated) {
+                    delegator = (*it).fullName();
+                    delegatorRSVP = (*it).RSVP();
                     break;
                 }
             }
         }
 
-        if (status != Attendee::NeedsAction && ((myself && (myself->RSVP() || myself->status() == Attendee::NeedsAction)) || heuristicalRSVP(incidence))) {
-            Attendee::Ptr newMyself = setStatusOnMyself(incidence, myself, status, receiver);
-            if (newMyself && status == Attendee::Delegated) {
-                newMyself->setDelegate(delegateString);
-                newMyself->setRSVP(delegatorRSVP);
+        if (status != Attendee::NeedsAction && ((!myself.isNull() && (myself.RSVP() || myself.status() == Attendee::NeedsAction)) || heuristicalRSVP(incidence))) {
+            Attendee newMyself = setStatusOnMyself(incidence, myself, status, receiver);
+            if (!newMyself.isNull() && status == Attendee::Delegated) {
+                newMyself.setDelegate(delegateString);
+                newMyself.setRSVP(delegatorRSVP);
             }
             ok = mail(viewerInstance, incidence, dir, iTIPReply, receiver);
 
             // check if we need to inform our delegator about this as well
-            if (newMyself
+            if (!newMyself.isNull()
                 && (status == Attendee::Accepted || status == Attendee::Declined)
                 && !delegator.isEmpty()) {
                 if (delegatorRSVP || status == Attendee::Declined) {
                     ok = mail(viewerInstance, incidence, dir, iTIPReply, receiver, delegator);
                 }
             }
-        } else if (!myself && (status != Attendee::Declined && status != Attendee::NeedsAction)) {
+        } else if (myself.isNull() && (status != Attendee::Declined && status != Attendee::NeedsAction)) {
             // forwarded invitation
             QString name;
             QString email;
             KEmailAddress::extractEmailAddressAndName(receiver, email, name);
             if (!email.isEmpty()) {
-                Attendee::Ptr newMyself(
-                    new Attendee(name, email, true,  // RSVP, otherwise we would not be here
+                Attendee newMyself(name, email, true,  // RSVP, otherwise we would not be here
                                  status,
                                  heuristicalRole(incidence),
-                                 QString()));
+                                 QString());
                 incidence->clearAttendees();
                 incidence->addAttendee(newMyself);
                 ok = mail(viewerInstance, incidence, dir, iTIPReply, receiver);
@@ -990,15 +996,17 @@ public:
         // our calendar
         if (status == Attendee::Delegated) {
             incidence = stringToIncidence(iCal);
-            myself = findMyself(incidence, receiver);
-            if (myself) {
-                myself->setStatus(status);
-                myself->setDelegate(delegateString);
+            auto attendees = incidence->attendees();
+            const int myselfIdx = findMyself(attendees, receiver);
+            if (myselfIdx >= 0) {
+                attendees[myselfIdx].setStatus(status);
+                attendees[myselfIdx].setDelegate(delegateString);
+                incidence->setAttendees(attendees);
             }
             QString name, email;
             KEmailAddress::extractEmailAddressAndName(delegateString, email, name);
-            Attendee::Ptr delegate(new Attendee(name, email, true));
-            delegate->setDelegator(receiver);
+            Attendee delegate(name, email, true);
+            delegate.setDelegator(receiver);
             incidence->addAttendee(delegate);
 
             ICalFormat format;
@@ -1015,18 +1023,18 @@ public:
 
     bool openAttachment(const QString &name, const QString &iCal) const
     {
-        Attachment::Ptr attachment(findAttachment(name, iCal));
-        if (!attachment) {
+        Attachment attachment(findAttachment(name, iCal));
+        if (attachment.isEmpty()) {
             return false;
         }
 
-        if (attachment->isUri()) {
-            QDesktopServices::openUrl(QUrl(attachment->uri()));
+        if (attachment.isUri()) {
+            QDesktopServices::openUrl(QUrl(attachment.uri()));
         } else {
             // put the attachment in a temporary file and launch it
             QTemporaryFile *file = nullptr;
             QMimeDatabase db;
-            QStringList patterns = db.mimeTypeForName(attachment->mimeType()).globPatterns();
+            QStringList patterns = db.mimeTypeForName(attachment.mimeType()).globPatterns();
             if (!patterns.empty()) {
                 QString pattern = patterns.at(0);
                 file = new QTemporaryFile(QDir::tempPath() + QStringLiteral("/messageviewer_XXXXXX") + pattern.remove(QLatin1Char('*')));
@@ -1036,12 +1044,12 @@ public:
             file->setAutoRemove(false);
             file->open();
             file->setPermissions(QFile::ReadUser);
-            file->write(QByteArray::fromBase64(attachment->data()));
+            file->write(QByteArray::fromBase64(attachment.data()));
             file->close();
 
             KRun::RunFlags flags;
             flags |= KRun::DeleteTemporaryFiles;
-            bool stat = KRun::runUrl(QUrl::fromLocalFile(file->fileName()), attachment->mimeType(), nullptr, flags);
+            bool stat = KRun::runUrl(QUrl::fromLocalFile(file->fileName()), attachment.mimeType(), nullptr, flags);
             delete file;
             return stat;
         }
@@ -1050,8 +1058,8 @@ public:
 
     bool saveAsAttachment(const QString &name, const QString &iCal) const
     {
-        Attachment::Ptr a(findAttachment(name, iCal));
-        if (!a) {
+        Attachment a(findAttachment(name, iCal));
+        if (a.isEmpty()) {
             return false;
         }
 
@@ -1063,9 +1071,9 @@ public:
         }
 
         bool stat = false;
-        if (a->isUri()) {
+        if (a.isUri()) {
             // save the attachment url
-            auto job = KIO::file_copy(QUrl(a->uri()), QUrl::fromLocalFile(saveAsFile));
+            auto job = KIO::file_copy(QUrl(a.uri()), QUrl::fromLocalFile(saveAsFile));
             stat = job->exec();
         } else {
             // put the attachment in a temporary file and save it
@@ -1073,7 +1081,7 @@ public:
                 nullptr
             };
             QMimeDatabase db;
-            QStringList patterns = db.mimeTypeForName(a->mimeType()).globPatterns();
+            QStringList patterns = db.mimeTypeForName(a.mimeType()).globPatterns();
             if (!patterns.empty()) {
                 QString pattern = patterns.at(0);
                 file = new QTemporaryFile(QDir::tempPath() + QStringLiteral("/messageviewer_XXXXXX") + pattern.remove(QLatin1Char('*')));
@@ -1083,7 +1091,7 @@ public:
             file->setAutoRemove(false);
             file->open();
             file->setPermissions(QFile::ReadUser);
-            file->write(QByteArray::fromBase64(a->data()));
+            file->write(QByteArray::fromBase64(a.data()));
             file->close();
             const QString filename = file->fileName();
             delete file;
@@ -1346,7 +1354,7 @@ public:
                 }
 
                 QUrlQuery query;
-                query.addQueryItem(QStringLiteral("to"), incidence->organizer()->email());
+                query.addQueryItem(QStringLiteral("to"), incidence->organizer().email());
                 query.addQueryItem(QStringLiteral("subject"), summary);
                 QUrl url;
                 url.setScheme(QStringLiteral("mailto"));
