@@ -23,7 +23,7 @@
 #include "testutils.h"
 #include "../eventdatavisitor.h"
 
-#include <QtTest/QTest>
+#include <QTest>
 
 #include <KCalCore/Event>
 #include <KCalCore/Todo>
@@ -268,7 +268,7 @@ void EventDataVisitorTest::testEventDataIdVisitor_data()
     for (const auto &testData : allTestData) {
         TestDataParser parser(testData, true);
         QStringList uids;
-        Q_FOREACH (const auto &ed, parser.eventData()) {
+        for (const auto &ed : parser.eventData()) {
             uids.push_back(ed.uid());
         }
         QTest::newRow(qPrintable(testData)) << parser.rangeStart()
